[Python-checkins] r61772 - in python/branches/trunk-bytearray/Lib: codecs.py io.py test/test_io.py

christian.heimes python-checkins at python.org
Sat Mar 22 23:24:53 CET 2008


Author: christian.heimes
Date: Sat Mar 22 23:24:52 2008
New Revision: 61772

Added:
   python/branches/trunk-bytearray/Lib/io.py
      - copied, changed from r61746, python/branches/py3k/Lib/io.py
   python/branches/trunk-bytearray/Lib/test/test_io.py
      - copied, changed from r61746, python/branches/py3k/Lib/test/test_io.py
Modified:
   python/branches/trunk-bytearray/Lib/codecs.py
Log:
Added backport of the io module

Modified: python/branches/trunk-bytearray/Lib/codecs.py
==============================================================================
--- python/branches/trunk-bytearray/Lib/codecs.py	(original)
+++ python/branches/trunk-bytearray/Lib/codecs.py	Sat Mar 22 23:24:52 2008
@@ -181,6 +181,18 @@
         Resets the encoder to the initial state.
         """
 
+    def getstate(self):
+        """
+        Return the current state of the encoder.
+        """
+        return 0
+
+    def setstate(self, state):
+        """
+        Set the current state of the encoder. state must have been
+        returned by getstate().
+        """
+
 class BufferedIncrementalEncoder(IncrementalEncoder):
     """
     This subclass of IncrementalEncoder can be used as the baseclass for an
@@ -208,6 +220,12 @@
         IncrementalEncoder.reset(self)
         self.buffer = ""
 
+    def getstate(self):
+        return self.buffer or 0
+
+    def setstate(self, state):
+        self.buffer = state or ""
+
 class IncrementalDecoder(object):
     """
     An IncrementalDecoder decodes an input in multiple steps. The input can be
@@ -235,6 +253,28 @@
         Resets the decoder to the initial state.
         """
 
+    def getstate(self):
+        """
+        Return the current state of the decoder.
+
+        This must be a (buffered_input, additional_state_info) tuple.
+        buffered_input must be a bytes object containing bytes that
+        were passed to decode() that have not yet been converted.
+        additional_state_info must be a non-negative integer
+        representing the state of the decoder WITHOUT yet having
+        processed the contents of buffered_input.  In the initial state
+        and after reset(), getstate() must return (b"", 0).
+        """
+        return (b"", 0)
+
+    def setstate(self, state):
+        """
+        Set the current state of the decoder.
+
+        state must have been returned by getstate().  The effect of
+        setstate((b"", 0)) must be equivalent to reset().
+        """
+
 class BufferedIncrementalDecoder(IncrementalDecoder):
     """
     This subclass of IncrementalDecoder can be used as the baseclass for an
@@ -262,6 +302,14 @@
         IncrementalDecoder.reset(self)
         self.buffer = ""
 
+    def getstate(self):
+        # additional state info is always 0
+        return (self.buffer, 0)
+
+    def setstate(self, state):
+        # ignore additional state info
+        self.buffer = state[0]
+
 #
 # The StreamWriter and StreamReader class provide generic working
 # interfaces which can be used to implement new encoding submodules

Copied: python/branches/trunk-bytearray/Lib/io.py (from r61746, python/branches/py3k/Lib/io.py)
==============================================================================
--- python/branches/py3k/Lib/test/test_io.py	(original)
+++ python/branches/trunk-bytearray/Lib/test/test_io.py	Sat Mar 22 23:24:52 2008
@@ -1,4 +1,5 @@
 """Unit tests for io.py."""
+from __future__ import print_function
 
 import os
 import sys
@@ -1001,7 +1002,7 @@
                 print("Reading using readline(): %6.3f seconds" % (t3-t2))
                 print("Using readline()+tell():  %6.3f seconds" % (t4-t3))
 
-    def testReadOneByOne(self):
+    def XXXtestReadOneByOne(self):
         txt = io.TextIOWrapper(io.BytesIO(b"AA\r\nBB"))
         reads = ""
         while True:
@@ -1012,7 +1013,7 @@
         self.assertEquals(reads, "AA\nBB")
 
     # read in amounts equal to TextIOWrapper._CHUNK_SIZE which is 128.
-    def testReadByChunk(self):
+    def XXXtestReadByChunk(self):
         # make sure "\r\n" straddles 128 char boundary.
         txt = io.TextIOWrapper(io.BytesIO(b"A" * 127 + b"\r\nB"))
         reads = ""
@@ -1023,7 +1024,7 @@
             reads += c
         self.assertEquals(reads, "A"*127+"\nB")
 
-    def test_issue1395_1(self):
+    def XXXtest_issue1395_1(self):
         txt = io.TextIOWrapper(io.BytesIO(self.testdata), encoding="ascii")
 
         # read one char at a time
@@ -1035,7 +1036,7 @@
             reads += c
         self.assertEquals(reads, self.normalized)
 
-    def test_issue1395_2(self):
+    def XXXtest_issue1395_2(self):
         txt = io.TextIOWrapper(io.BytesIO(self.testdata), encoding="ascii")
         txt._CHUNK_SIZE = 4
 
@@ -1047,7 +1048,7 @@
             reads += c
         self.assertEquals(reads, self.normalized)
 
-    def test_issue1395_3(self):
+    def XXXtest_issue1395_3(self):
         txt = io.TextIOWrapper(io.BytesIO(self.testdata), encoding="ascii")
         txt._CHUNK_SIZE = 4
 
@@ -1058,7 +1059,7 @@
         reads += txt.readline()
         self.assertEquals(reads, self.normalized)
 
-    def test_issue1395_4(self):
+    def XXXtest_issue1395_4(self):
         txt = io.TextIOWrapper(io.BytesIO(self.testdata), encoding="ascii")
         txt._CHUNK_SIZE = 4
 


More information about the Python-checkins mailing list
--- python/branches/py3k/Lib/io.py	(original)
+++ python/branches/trunk-bytearray/Lib/io.py	Sat Mar 22 23:24:52 2008
@@ -39,6 +39,8 @@
 # open() uses st_blksize whenever we can
 DEFAULT_BUFFER_SIZE = 8 * 1024  # bytes
 
+# py3k has only new style classes
+__metaclass__ = type
 
 class BlockingIOError(IOError):
 
@@ -108,7 +110,7 @@
       binary stream, a buffered binary stream, or a buffered text
       stream, open for reading and/or writing.
     """
-    if not isinstance(file, (str, int)):
+    if not isinstance(file, (str, unicode, int)):
         raise TypeError("invalid file: %r" % file)
     if not isinstance(mode, str):
         raise TypeError("invalid mode: %r" % mode)
@@ -216,7 +218,7 @@
     pass
 
 
-class IOBase(metaclass=abc.ABCMeta):
+class IOBase(object):
 
     """Base class for all I/O classes.
 
@@ -232,16 +234,18 @@
     undefined.  Implementations may raise IOError in this case.
     """
 
+    __metaclass__ = abc.ABCMeta
+
     ### Internal ###
 
-    def _unsupported(self, name: str) -> IOError:
+    def _unsupported(self, name):
         """Internal: raise an exception for unsupported operations."""
         raise UnsupportedOperation("%s.%s() not supported" %
                                    (self.__class__.__name__, name))
 
     ### Positioning ###
 
-    def seek(self, pos: int, whence: int = 0) -> int:
+    def seek(self, pos, whence = 0):
         """seek(pos: int, whence: int = 0) -> int.  Change stream position.
 
         Seek to byte offset pos relative to position indicated by whence:
@@ -252,11 +256,11 @@
         """
         self._unsupported("seek")
 
-    def tell(self) -> int:
+    def tell(self):
         """tell() -> int.  Return current stream position."""
         return self.seek(0, 1)
 
-    def truncate(self, pos: int = None) -> int:
+    def truncate(self, pos = None):
         """truncate(size: int = None) -> int. Truncate file to size bytes.
 
         Size defaults to the current IO position as reported by tell().
@@ -266,7 +270,7 @@
 
     ### Flush and close ###
 
-    def flush(self) -> None:
+    def flush(self):
         """flush() -> None.  Flushes write buffers, if applicable.
 
         This is a no-op for read-only and non-blocking streams.
@@ -275,7 +279,7 @@
 
     __closed = False
 
-    def close(self) -> None:
+    def close(self):
         """close() -> None.  Flushes and closes the IO object.
 
         This must be idempotent.  It should also set a flag for the
@@ -288,7 +292,7 @@
                 pass  # If flush() fails, just give up
             self.__closed = True
 
-    def __del__(self) -> None:
+    def __del__(self):
         """Destructor.  Calls close()."""
         # The try/except block is in case this is called at program
         # exit time, when it's possible that globals have already been
@@ -302,7 +306,7 @@
 
     ### Inquiries ###
 
-    def seekable(self) -> bool:
+    def seekable(self):
         """seekable() -> bool.  Return whether object supports random access.
 
         If False, seek(), tell() and truncate() will raise IOError.
@@ -318,7 +322,7 @@
                           if msg is None else msg)
 
 
-    def readable(self) -> bool:
+    def readable(self):
         """readable() -> bool.  Return whether object was opened for reading.
 
         If False, read() will raise IOError.
@@ -332,7 +336,7 @@
             raise IOError("File or stream is not readable."
                           if msg is None else msg)
 
-    def writable(self) -> bool:
+    def writable(self):
         """writable() -> bool.  Return whether object was opened for writing.
 
         If False, write() and truncate() will raise IOError.
@@ -363,12 +367,12 @@
 
     ### Context manager ###
 
-    def __enter__(self) -> "IOBase":  # That's a forward reference
+    def __enter__(self):
         """Context management protocol.  Returns self."""
         self._checkClosed()
         return self
 
-    def __exit__(self, *args) -> None:
+    def __exit__(self, *args):
         """Context management protocol.  Calls close()"""
         self.close()
 
@@ -376,14 +380,14 @@
 
     # XXX Should these be present even if unimplemented?
 
-    def fileno(self) -> int:
+    def fileno(self):
         """fileno() -> int.  Returns underlying file descriptor if one exists.
 
         Raises IOError if the IO object does not use a file descriptor.
         """
         self._unsupported("fileno")
 
-    def isatty(self) -> bool:
+    def isatty(self):
         """isatty() -> int.  Returns whether this is an 'interactive' stream.
 
         Returns False if we don't know.
@@ -393,7 +397,7 @@
 
     ### Readline[s] and writelines ###
 
-    def readline(self, limit: int = -1) -> bytes:
+    def readline(self, limit = -1):
         """For backwards compatibility, a (slowish) readline()."""
         if hasattr(self, "peek"):
             def nreadahead():
@@ -462,7 +466,7 @@
     recursion in case a subclass doesn't implement either.)
     """
 
-    def read(self, n: int = -1) -> bytes:
+    def read(self, n = -1):
         """read(n: int) -> bytes.  Read and return up to n bytes.
 
         Returns an empty bytes array on EOF, or None if the object is
@@ -487,7 +491,7 @@
             res += data
         return bytes(res)
 
-    def readinto(self, b: bytes) -> int:
+    def readinto(self, b):
         """readinto(b: bytes) -> int.  Read up to len(b) bytes into b.
 
         Returns number of bytes read (0 for EOF), or None if the object
@@ -495,7 +499,7 @@
         """
         self._unsupported("readinto")
 
-    def write(self, b: bytes) -> int:
+    def write(self, b):
         """write(b: bytes) -> int.  Write the given buffer to the IO stream.
 
         Returns the number of bytes written, which may be less than len(b).
@@ -543,7 +547,7 @@
     implementation, but wrap one.
     """
 
-    def read(self, n: int = None) -> bytes:
+    def read(self, n = None):
         """read(n: int = None) -> bytes.  Read and return up to n bytes.
 
         If the argument is omitted, None, or negative, reads and
@@ -563,7 +567,7 @@
         """
         self._unsupported("read")
 
-    def readinto(self, b: bytes) -> int:
+    def readinto(self, b):
         """readinto(b: bytes) -> int.  Read up to len(b) bytes into b.
 
         Like read(), this may issue multiple reads to the underlying
@@ -587,7 +591,7 @@
             b[:n] = array.array('b', data)
         return n
 
-    def write(self, b: bytes) -> int:
+    def write(self, b):
         """write(b: bytes) -> int.  Write the given buffer to the IO stream.
 
         Returns the number of bytes written, which is never less than
@@ -698,8 +702,8 @@
     def write(self, b):
         if self.closed:
             raise ValueError("write to closed file")
-        if isinstance(b, str):
-            raise TypeError("can't write str to binary stream")
+        if isinstance(b, unicode):
+            raise TypeError("can't write unicode to binary stream")
         n = len(b)
         newpos = self._pos + n
         if newpos > len(self._buffer):
@@ -715,7 +719,7 @@
         try:
             pos = pos.__index__()
         except AttributeError as err:
-            raise TypeError("an integer is required") from err
+            raise TypeError("an integer is required") # from err
         if whence == 0:
             self._pos = max(0, pos)
         elif whence == 1:
@@ -840,8 +844,8 @@
     def write(self, b):
         if self.closed:
             raise ValueError("write to closed file")
-        if isinstance(b, str):
-            raise TypeError("can't write str to binary stream")
+        if isinstance(b, unicode):
+            raise TypeError("can't write unicode to binary stream")
         # XXX we can implement some more tricks to try and avoid partial writes
         if len(self._write_buf) > self.buffer_size:
             # We're full, so let's pre-flush the buffer
@@ -1009,19 +1013,19 @@
     There is no readinto() method, as character strings are immutable.
     """
 
-    def read(self, n: int = -1) -> str:
-        """read(n: int = -1) -> str.  Read at most n characters from stream.
+    def read(self, n = -1):
+        """read(n: int = -1) -> unicode.  Read at most n characters from stream.
 
         Read from underlying buffer until we have n characters or we hit EOF.
         If n is negative or omitted, read until EOF.
         """
         self._unsupported("read")
 
-    def write(self, s: str) -> int:
-        """write(s: str) -> int.  Write string s to stream."""
+    def write(self, s):
+        """write(s: unicode) -> int.  Write string s to stream."""
         self._unsupported("write")
 
-    def truncate(self, pos: int = None) -> int:
+    def truncate(self, pos = None):
         """truncate(pos: int = None) -> int.  Truncate size to pos."""
         self.flush()
         if pos is None:
@@ -1029,8 +1033,8 @@
         self.seek(pos)
         return self.buffer.truncate()
 
-    def readline(self) -> str:
-        """readline() -> str.  Read until newline or EOF.
+    def readline(self):
+        """readline() -> unicode.  Read until newline or EOF.
 
         Returns an empty string if EOF is hit immediately.
         """
@@ -1043,7 +1047,7 @@
 
     @property
     def newlines(self):
         """newlines -> None | str | tuple of str. Line endings translated
         so far.
 
         Only line endings translated during reading are considered.
@@ -1232,10 +1236,10 @@
     def isatty(self):
         return self.buffer.isatty()
 
-    def write(self, s: str):
+    def write(self, s):
         if self.closed:
             raise ValueError("write to closed file")
-        if not isinstance(s, str):
+        if not isinstance(s, unicode):
             raise TypeError("can't write %s to text stream" %
                             s.__class__.__name__)
         length = len(s)
@@ -1587,8 +1591,8 @@
                                        errors=errors,
                                        newline=newline)
         if initial_value:
-            if not isinstance(initial_value, str):
-                initial_value = str(initial_value)
+            if not isinstance(initial_value, unicode):
+                initial_value = unicode(initial_value)
             self.write(initial_value)
             self.seek(0)
 
@@ -1043,7 +1047,7 @@
     @property
     def newlines(self):
-        """newlines -> None | str | tuple of str. Line endings translated
+        """newlines -> None | unicode | tuple of unicode. Line endings translated
         so far.
 

Copied: python/branches/trunk-bytearray/Lib/test/test_io.py (from r61746, python/branches/py3k/Lib/test/test_io.py)
==============================================================================